@@ -38,7 +38,9 @@ import GHC.Generics (Generic)
 import Text.Pretty.Simple.Internal.Expr (CommaSeparated(..), Expr(..))
 import Text.Pretty.Simple.Internal.Output
        (NestLevel(..), Output(..), OutputType(..), unNestLevel)
+
 -- $setup
+-- >>> :set -XOverloadedStrings
 -- >>> import Control.Monad.State (State)
 -- >>> :{
 -- let test :: PrinterState -> State PrinterState [Output] -> [Output]
@@ -143,7 +145,7 @@ putSurroundExpr startOutputType endOutputType (CommaSeparated [exprs]) = do
     isMultiLine (Braces commaSeparated) = isMultiLine' commaSeparated
     isMultiLine (Parens commaSeparated) = isMultiLine' commaSeparated
     isMultiLine _ = (False, False)
-    
+
     isMultiLine' (CommaSeparated []) = (False, False)
     isMultiLine' (CommaSeparated [es]) = (True, fst $ thisAndNextMulti es)
     isMultiLine' _ = (True, True)
@@ -215,7 +217,7 @@ addToCurrentLine diff =
   modify (\printState -> printState {currLine = currLine printState + diff})
 
 putExpression :: MonadState PrinterState m => Expr -> m [Output]
-putExpression (Brackets commaSeparated) = 
+putExpression (Brackets commaSeparated) =
   putSurroundExpr OutputOpenBracket OutputCloseBracket commaSeparated
 putExpression (Braces commaSeparated) =
   putSurroundExpr OutputOpenBrace OutputCloseBrace commaSeparated
@@ -225,6 +227,14 @@ putExpression (StringLit string) = do
   nest <- gets nestLevel
   when (nest < 0) $ addToNestLevel 1
   addOutputs [OutputStringLit string, OutputOther " "]
+putExpression (CharLit string) = do
+  nest <- gets nestLevel
+  when (nest < 0) $ addToNestLevel 1
+  addOutputs [OutputCharLit string, OutputOther " "]
+putExpression (NumberLit integer) = do
+  nest <- gets nestLevel
+  when (nest < 0) $ addToNestLevel 1
+  (:[]) <$> (addOutput $ OutputNumberLit integer)
 putExpression (Other string) = do
   nest <- gets nestLevel
   when (nest < 0) $ addToNestLevel 1
